## Screen Recorder

Record the screen of your Android or iOS devices and simulators, and convert them to GIFs with a single command.

#### Requirements

Screen Recorder requires Python 3 or later.

#### Installation

Install Screen Recorder via PyPI:

```bash
pip install screen-recorder
```

#### Usage

After installation, run the following commands to record a screen:

```bash
# To record an Android device or emulator
>> screen-recorder android  

# To record an iOS device or simulator
>> screen-recorder ios
```

That’s it—enjoy!